@@ -3,8 +3,7 @@ from sklearn.pipeline import Pipeline
 # from feature-engine
 from feature_engine.imputation import MeanMedianImputer,AddMissingIndicator
 
-from feature_engine.encoding import OneHotEncoder
-from sklearn.linear_model import LogisticRegression
+from sklearn.naive_bayes import GaussianNB
 from model.config.core import config
 
 pipe = Pipeline([
@@ -23,8 +22,6 @@ pipe = Pipeline([
             variables=config.model_config.numerical_vars_with_na,
         ),
     ),
-    ('categorical_encoder', OneHotEncoder(top_categories=1, variables=config.model_config.categorical_vars
-    )),
-    ('LogisticRegression', LogisticRegression())
+    ('GaussianNB', GaussianNB())
    
    ])
\ No newline at end of file
